The generic power off callback is pm_power_off. Use that one rather than
the powerpc specific ppc_md.power_off.

Signed-off-by: Alexander Graf <ag...@suse.de>
---
 arch/powerpc/platforms/83xx/mcu_mpc8349emitx.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/arch/powerpc/platforms/83xx/mcu_mpc8349emitx.c 
b/arch/powerpc/platforms/83xx/mcu_mpc8349emitx.c
index 463fa91e..15e8021 100644
--- a/arch/powerpc/platforms/83xx/mcu_mpc8349emitx.c
+++ b/arch/powerpc/platforms/83xx/mcu_mpc8349emitx.c
@@ -167,10 +167,10 @@ static int mcu_probe(struct i2c_client *client, const 
struct i2c_device_id *id)
        if (ret)
                goto err;
 
-       /* XXX: this is potentially racy, but there is no lock for ppc_md */
-       if (!ppc_md.power_off) {
+       /* XXX: this is potentially racy, but there is no lock for pm_power_off 
*/
+       if (!pm_power_off) {
                glob_mcu = mcu;
-               ppc_md.power_off = mcu_power_off;
+               pm_power_off = mcu_power_off;
                dev_info(&client->dev, "will provide power-off service\n");
        }
 
@@ -197,7 +197,7 @@ static int mcu_remove(struct i2c_client *client)
        device_remove_file(&client->dev, &dev_attr_status);
 
        if (glob_mcu == mcu) {
-               ppc_md.power_off = NULL;
+               pm_power_off = NULL;
                glob_mcu = NULL;
        }
 
-- 
1.8.1.4

_______________________________________________
Linuxppc-dev mailing list
Linuxppc-dev@lists.ozlabs.org
https://lists.ozlabs.org/listinfo/linuxppc-dev

Reply via email to